@@ -15,12 +15,11 @@ extern SEXP _elmNNRcpp_hardlim(SEXP);
 extern SEXP _elmNNRcpp_hardlims(SEXP);
 extern SEXP _elmNNRcpp_norm_preds(SEXP);
 extern SEXP _elmNNRcpp_onehot_labels_rcpp(SEXP);
-extern SEXP _elmNNRcpp_randomMatrix(SEXP, SEXP, SEXP, SEXP);
 extern SEXP _elmNNRcpp_relu(SEXP, SEXP);
 extern SEXP _elmNNRcpp_satlins(SEXP);
 extern SEXP _elmNNRcpp_set_seed(SEXP);
 extern SEXP _elmNNRcpp_tribas(SEXP);
-extern SEXP _elmNNRcpp_uniform_vector(SEXP, SEXP, SEXP);
+extern SEXP _elmNNRcpp_uniform_negative(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"_elmNNRcpp_activation_functions", (DL_FUNC) &_elmNNRcpp_activation_functions,  3},
@@ -30,12 +29,11 @@ static const R_CallMethodDef CallEntries[] = {
     {"_elmNNRcpp_hardlims",             (DL_FUNC) &_elmNNRcpp_hardlims,              1},
     {"_elmNNRcpp_norm_preds",           (DL_FUNC) &_elmNNRcpp_norm_preds,            1},
     {"_elmNNRcpp_onehot_labels_rcpp",   (DL_FUNC) &_elmNNRcpp_onehot_labels_rcpp,    1},
-    {"_elmNNRcpp_randomMatrix",         (DL_FUNC) &_elmNNRcpp_randomMatrix,          4},
     {"_elmNNRcpp_relu",                 (DL_FUNC) &_elmNNRcpp_relu,                  2},
     {"_elmNNRcpp_satlins",              (DL_FUNC) &_elmNNRcpp_satlins,               1},
     {"_elmNNRcpp_set_seed",             (DL_FUNC) &_elmNNRcpp_set_seed,              1},
     {"_elmNNRcpp_tribas",               (DL_FUNC) &_elmNNRcpp_tribas,                1},
-    {"_elmNNRcpp_uniform_vector",       (DL_FUNC) &_elmNNRcpp_uniform_vector,        3},
+    {"_elmNNRcpp_uniform_negative",     (DL_FUNC) &_elmNNRcpp_uniform_negative,      2},
     {NULL, NULL, 0}
 };
 
